@@ -15,14 +15,14 @@ Net::SNTP::Client - Perl module to calculate the roundtrip delay d and
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 
 =cut
 
 ## Version of the Net::SNTP::Client module
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 $VERSION = eval $VERSION;
 
 
@@ -569,7 +569,7 @@ L<http://search.cpan.org/dist/Net-SNTP-Client/>
 
 =head1 SEE ALSO
 
-perl, IO::Socket, Net::NTP, Net::SNTP::Server, RFC4330
+perl, IO::Socket, Net::NTP, Net::SNTP::Server, L<RFC4330|https://tools.ietf.org/html/rfc4330>
 
 Net::NTP has a similar focus as this module. In my opinion it
  is less accurate when it comes to the precission bellow second(s).
@@ -642,7 +642,7 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =head1 CHANGE LOG
 $Log: Client.pm,v $
-Revision 17.0  2015/09/16 4:21:31 pm  Thanos
+Revision 18.0  2015/09/16 6:27:21 pm  Thanos
 
 =cut
 
